@@ -37,7 +37,9 @@ from pysollib.kivy.LApp import LScrollView
 from pysollib.kivy.LApp import LTopLevel
 from pysollib.kivy.LApp import LTreeNode
 from pysollib.kivy.LApp import LTreeRoot
+from pysollib.kivy.LApp import LTreeSliderNode
 from pysollib.kivy.LObjWrap import LBoolWrap
+from pysollib.kivy.LObjWrap import LListWrap
 from pysollib.kivy.LObjWrap import LNumWrap
 from pysollib.kivy.LObjWrap import LStringWrap
 from pysollib.kivy.androidrot import AndroidScreenRotation
@@ -132,6 +134,11 @@ class LMenuBase(object):
                       variable=auto_var, value=auto_val), rg)
         return rg1
 
+    def addSliderNode(self, tv, rg, auto_var, auto_setup):
+        rg1 = tv.add_node(
+            LTreeSliderNode(variable=auto_var, setup=auto_setup), rg)
+        return rg1
+
 # ************************************************************************
 # * Tree Generators
 # ************************************************************************
@@ -349,6 +356,9 @@ class FileMenuDialog(LMenuDialog):
 
             self.make_favid_list(tv, rg)
 
+        tv.add_node(LTreeNode(
+            text=_('Random game'),
+            command=self.make_command(self.menubar.mSelectRandomGame)))
         tv.add_node(LTreeNode(
             text=_('Load'), command=self.make_command(self.menubar.mOpen)))
         tv.add_node(LTreeNode(
@@ -386,6 +396,9 @@ class EditMenuDialog(LMenuDialog):  # Tools
             text=_('Shuffle tiles'), command=self.menubar.mShuffle))
         tv.add_node(LTreeNode(
             text=_('Deal cards'), command=self.menubar.mDeal))
+        tv.add_node(LTreeNode(
+            text=_('Reset zoom'),
+            command=self.auto_close(self.menubar.mResetZoom)))
 
         self.addCheckNode(tv, None,
                           _('Pause'),
@@ -1255,6 +1268,38 @@ class LOptionsMenuGenerator(LTreeGenerator):
         # -------------------------------------------
         # general options
 
+        rg = tv.add_node(
+            LTreeNode(text=_('Font size')))
+        if rg:
+            self.addRadioNode(tv, rg,
+                              _('default'),
+                              self.menubar.tkopt.fontscale, 'default',
+                              None)
+            self.addRadioNode(tv, rg,
+                              _('tiny'),
+                              self.menubar.tkopt.fontscale, 'tiny',
+                              None)
+            self.addRadioNode(tv, rg,
+                              _('small'),
+                              self.menubar.tkopt.fontscale, 'small',
+                              None)
+            self.addRadioNode(tv, rg,
+                              _('normal'),
+                              self.menubar.tkopt.fontscale, 'normal',
+                              None)
+            self.addRadioNode(tv, rg,
+                              _('large'),
+                              self.menubar.tkopt.fontscale, 'large',
+                              None)
+            self.addRadioNode(tv, rg,
+                              _('huge'),
+                              self.menubar.tkopt.fontscale, 'huge',
+                              None)
+            '''
+            self.addSliderNode(tv, rg, self.menubar.tkopt.fontsizefactor,
+                               (0.7, 2.0, 0.1))
+            '''
+
         # self.addCheckNode(tv, None,
         #   'Save games geometry',
         #   self.menubar.tkopt.save_games_geometry,
@@ -1429,6 +1474,25 @@ class PysolMenubarTk:
         AndroidScreenRotation.unlock(toaster=False)
         print('unlock screen rotation')
 
+    def setFontScale(self, obj, val):
+        from kivy.metrics import Metrics
+        vals = {
+            'tiny':   0.833,
+            'small':  1.0,
+            'normal': 1.2,
+            'large':  1.44,
+            'huge':   1.728
+        }
+        if val == 'default':
+            Metrics.reset_metrics()
+        else:
+            Metrics.fontscale = vals[val]
+    '''
+    def setFontSize(self, obj, val):
+        from kivy.metrics import Metrics
+        Metrics.fontscale = val
+    '''
+
     def _createTkOpt(self):
         opt = self.app.opt
 
@@ -1531,6 +1595,9 @@ class PysolMenubarTk:
             language=LStringWrap(opt, "language"),
             save_games_geometry=LBoolWrap(opt, "save_games_geometry"),
             pause=LBoolWrap(self, "pause"),
+            table_zoom=LListWrap(opt, "table_zoom"),
+            fontscale=LStringWrap(opt, "fontscale", self.setFontScale),
+            # fontsizefactor=LNumWrap(opt, "fontsizefactor", self.setFontSize),
             # cards
             cardset=LNumWrap(self, "cardset"),
             cardback=LNumWrap(self, "cardback"),
@@ -1549,9 +1616,10 @@ class PysolMenubarTk:
             self.tkopt.color_vars[k] = LStringWrap(self.cvo, k)
 
     def _setOptions(self):
-        # not supported
         self.tkopt.save_games_geometry.value = False
         self.getToolbarPos(None, Window.size)
+        self.setFontScale(None, self.tkopt.fontscale.value)
+        # self.setFontSize(None, self.tkopt.fontsizefactor.value)
         Window.bind(size=self.getToolbarPos)
 
     def getToolbarPos(self, obj, size):
@@ -2054,9 +2122,6 @@ class PysolMenubarTk:
         # LB: not used
         return
 
-    def _setCommentMenu(self, v):
-        return
-
     def _setPauseMenu(self, v):
         self.tkopt.pause.value = v
 
@@ -2092,7 +2157,7 @@ class PysolMenubarTk:
             idir, ifile = "", ""
         if not idir:
             idir = self.app.dn.savegames
-#        d = tkFileDialog.Open()
+#        d = tkinter.filedialog.Open()
 #        filename = d.show(filetypes=self.FILETYPES,
 #                          defaultextension=self.DEFAULTEXTENSION,
 #                          initialdir=idir, initialfile=ifile)
@@ -2139,6 +2204,9 @@ class PysolMenubarTk:
                 toast.show(parent=baseWindow, duration=5.0)
             self.updateMenus()
 
+    def mResetZoom(self, *args):
+        self.tkopt.table_zoom.value = [1.0, 0.0, 0.0]
+
     def mPause(self, *args):
         if not self.game:
             return
