@@ -23,6 +23,7 @@
 
 import os
 import tkinter
+import tkinter.ttk as ttk
 from collections import UserList
 
 from pysollib.gamedb import GI
@@ -33,8 +34,6 @@ from pysollib.resource import CSI
 from pysollib.ui.tktile.selecttree import SelectDialogTreeData
 from pysollib.ui.tktile.tkutil import bind, unbind_destroy
 
-from six.moves import tkinter_ttk as ttk
-
 from .selecttree import SelectDialogTreeCanvas
 from .selecttree import SelectDialogTreeLeaf, SelectDialogTreeNode
 from .tkwidget import MfxDialog, MfxScrolledCanvas, PysolCombo
@@ -677,6 +676,10 @@ class SelectGameDialogWithPreview(SelectGameDialog):
         d = SelectGameAdvancedSearch(self.top, _("Advanced search"),
                                      self.criteria)
         if d.status == 0 and d.button == 0:
+            self.criteria = SearchCriteria()
+            self.performSearch()
+
+        if d.status == 0 and d.button == 1:
             self.criteria.name = d.name.get()
 
             self.list_searchtext.delete(0, "end")
@@ -1228,6 +1231,9 @@ class SelectGameAdvancedSearch(MfxDialog):
                            padx=1, pady=1)
 
         focus = self.createButtons(bottom_frame, kw)
+
+        top_frame.config(width=bottom_frame.winfo_width())
+
         # focus = text_w
         self.mainloop(focus, kw.timeout)
 
@@ -1250,7 +1256,7 @@ class SelectGameAdvancedSearch(MfxDialog):
 
     def initKw(self, kw):
         kw = KwStruct(kw,
-                      strings=(_("&OK"), _("&Cancel")), default=0,
-                      padx=10, pady=10,
+                      strings=(_("C&lear"), 'sep', _("&OK"), _("&Cancel")),
+                      default=1, padx=10, pady=10,
                       )
         return MfxDialog.initKw(self, kw)
