@@ -23,6 +23,7 @@
 
 import time
 import tkinter
+import tkinter.font
 import traceback
 
 from pysollib.mfxutil import KwStruct, destruct, kwdefault, openURL
@@ -33,8 +34,6 @@ from pysollib.ui.tktile.tkutil import after, after_cancel
 from pysollib.ui.tktile.tkutil import bind, unbind_destroy
 from pysollib.ui.tktile.tkutil import makeToplevel, setTransient
 
-from six.moves import tkinter_font
-
 # ************************************************************************
 # * abstract base class for the dialogs in this module
 # ************************************************************************
@@ -307,7 +306,7 @@ class PysolAboutDialog(MfxMessageDialog):
                             width=kw.width)
         msg.pack(fill='both', expand=True)
 
-        font = tkinter_font.Font(parent, app.getFont('default'))
+        font = tkinter.font.Font(parent, app.getFont('default'))
         font.configure(underline=True)
         url_label = tkinter.Label(frame, text=kw.url, font=font,
                                   foreground='blue', cursor='hand2')
