@@ -22,6 +22,7 @@
 # ---------------------------------------------------------------------------##
 
 import os
+import tkinter
 
 from pysollib.mfxutil import Image, ImageTk
 from pysollib.mygettext import _, n_
@@ -31,8 +32,6 @@ from pysollib.ui.tktile.tkconst import EVENT_HANDLED
 from pysollib.util import IMAGE_EXTENSIONS
 from pysollib.winsystems import TkSettings
 
-from six.moves import tkinter
-
 from .tkwidget import MfxTooltip
 
 
@@ -171,7 +170,17 @@ class PysolToolbarTk:
         #
         self.frame = tkinter.Frame(top, relief=TkSettings.toolbar_relief,
                                    bd=TkSettings.toolbar_borderwidth)
-        #
+
+        from pysollib.options import calcCustomMouseButtonsBinding
+
+        def _bind2sep(sep):
+            sep.bind(
+                calcCustomMouseButtonsBinding("<{mouse_button1}>"),
+                self.clickHandler)
+            sep.bind(
+                calcCustomMouseButtonsBinding("<{mouse_button3}>"),
+                self.rightclickHandler)
+
         for label, f, t in (
             (n_("New"),      self.mNewGame,   _("New game")),
             (n_("Restart"),  self.mRestart,   _("Restart the\ncurrent game")),
@@ -183,17 +192,17 @@ class PysolToolbarTk:
             (n_("Redo"),     self.mRedo,      _("Redo last move")),
             (n_("Autodrop"), self.mDrop,      _("Auto drop cards")),
             (n_("Shuffle"),  self.mShuffle,   _("Shuffle tiles")),
+            (n_("Hint"),     self.mHint,      _("Hint")),
             (n_("Pause"),    self.mPause,     _("Pause game")),
             (None,           None,            None),
             (n_("Statistics"), self.mPlayerStats, _("View statistics")),
             (n_("Rules"),    self.mHelpRules, _("Rules for this game")),
             (None,           None,            None),
-            (n_("Quit"),     self.mQuit,      _("Quit ")+TITLE),
+            (n_("Quit"),     self.mQuit,      _("Quit %s") % TITLE),
                 ):
             if label is None:
                 sep = self._createSeparator()
-                sep.bind("<1>", self.clickHandler)
-                sep.bind("<3>", self.rightclickHandler)
+                _bind2sep(sep)
             elif label == 'Pause':
                 self._createButton(label, f, check=True, tooltip=t)
             else:
@@ -201,17 +210,17 @@ class PysolToolbarTk:
         self.pause_button.config(variable=menubar.tkopt.pause)
 
         sep = self._createFlatSeparator()
-        sep.bind("<1>", self.clickHandler)
-        sep.bind("<3>", self.rightclickHandler)
+        _bind2sep(sep)
         self._createLabel("player", label=n_('Player'),
                           tooltip=_("Player options"))
         #
-        self.player_label.bind("<1>", self.mOptPlayerOptions)
+        self.player_label.bind(
+            calcCustomMouseButtonsBinding("<{mouse_button1}>"),
+            self.mOptPlayerOptions)
         # self.player_label.bind("<3>",self.mOptPlayerOptions)
         self.popup = MfxMenu(master=None, label=n_('Toolbar'), tearoff=0)
         createToolbarMenu(menubar, self.popup)
-        self.frame.bind("<1>", self.clickHandler)
-        self.frame.bind("<3>", self.rightclickHandler)
+        _bind2sep(self.frame)
         #
         self.setCompound(compound, force=True)
 
